@@ -7,6 +7,9 @@ from lime_uow import resources, exceptions, _resource_manager
 __all__ = ("UnitOfWork",)
 
 
+T = typing.TypeVar("T", bound=resources.Resource[typing.Any])
+
+
 class UnitOfWork:
     def __init__(self, /, *resource: resources.Resource[typing.Any]):
         names = [resource.name for resource in resource]
@@ -33,15 +36,17 @@ class UnitOfWork:
             resource.close()
         self._activated = False
 
-    def get_resource(self, resource_name: str) -> typing.Any:
+    def get_resource(self, resource_type: typing.Type[T], /) -> T:
+        return self.get_resource_by_name(resource_type.__resource_name__)
+
+    def get_resource_by_name(self, resource_name: str) -> typing.Any:
         if not self._activated:
             raise exceptions.MissingTransactionBlock(
                 "Attempted access a resource managed by a UnitOfWork instance outside a `with` block."
             )
-
         try:
             mgr = self._resource_managers[resource_name]
-        except IndexError:
+        except KeyError:
             raise exceptions.MissingResourceError(resource_name)
 
         return mgr.open()
